@@ -109,7 +109,7 @@ class Field(MetricsLayerBase, SQLReplacement):
 
     @property
     def convert_timezone(self):
-        return self._definition.get("convert_timezone", True)
+        return self._definition.get("convert_timezone", True) and self._definition.get("convert_tz", True)
 
     @property
     def datatype(self):
@@ -821,4 +821,4 @@ class Field(MetricsLayerBase, SQLReplacement):
         extended = [f"merged_result_{mr}" for mr, _ in edges]
         if self.is_merged_result:
             return extended
-        return base + extended
+        return list(sorted(base + extended))
